@@ -13,7 +13,7 @@
 #endif
 
 #if defined(__FreeBSD__) || defined(__bsdi__)
-#undef _KU_SHADOW
+#undef HAVE_SHADOW
 #endif
 
 class KUsers;
@@ -49,7 +49,7 @@ public:
 
 #endif
 
-#ifdef _KU_SHADOW
+#ifdef HAVE_SHADOW
   const QString &getSPwd() const;
   long getLastChange() const;
   int getMin() const;
@@ -82,7 +82,7 @@ public:
   void setAddress(const QString &data);
 #endif
 
-#ifdef _KU_SHADOW
+#ifdef HAVE_SHADOW
   void setSPwd(const QString &data);
   void setLastChange(long data);
   void setMin(int data);
@@ -93,18 +93,20 @@ public:
   void setFlag(int data);
 #endif
 
-  int getCreateHome();
-  int getCreateMailBox();
-  int getCopySkel();
+  bool getCreateHome();
+  bool getCreateMailBox();
+  bool getCopySkel();
 
-  void setCreateHome(int data);
-  void setCreateMailBox(int data);
-  void setCopySkel(int data);
+  void setCreateHome(bool data);
+  void setCreateMailBox(bool data);
+  void setCopySkel(bool data);
 
 protected:
   friend class KUsers;
 
   void createHome();
+  int createKDE();
+  int tryCreate(const QString &dir);
   int createMailBox();
   int copySkel();
 
@@ -137,7 +139,7 @@ protected:
   uid_t p_uid;
   gid_t p_gid;
 
-#ifdef _KU_SHADOW
+#ifdef HAVE_SHADOW
   QString
     s_pwd;                         // parsed shadow information
   long
@@ -150,7 +152,7 @@ protected:
     s_expire,                      // date when account expires
     s_flag;                        // reserved for future use
 #endif
-  int
+  bool
     isCreateHome,              // create homedir
     isCreateMailBox,           // create mailbox
     isCopySkel;                // copy skeleton
@@ -177,7 +179,8 @@ public:
   void del(KUser *au);
 
 protected:
-  bool p_backuped;
+  bool pw_backuped;
+  bool pn_backuped;
   bool s_backuped;
 
   mode_t pwd_mode;
